@@ -14,7 +14,7 @@ class Spark(object):
     #region Static Methods
 
     @staticmethod
-    def get_single_row_result(df: DataFrame) -> Any:
+    def get_single_row_result(df: DataFrame) -> object:
 
         if not df:
             raise ValueError("data frame cannot be None...")
