@@ -9,7 +9,7 @@ class DimensionTestSuite(BaseTestSuite):
         super(DimensionTestSuite, self).__init__(sparkSession, databaseName, tableName)
 
     def queue_tests(self) -> None:
-        dimensionTestCase = DimensionTestCase(self.SparkSession, self.FieldInfo, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents)
+        dimensionTestCase = DimensionTestCase(self.SparkUtility, self.FieldInfo, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents)
         commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
         self.TestSuite.addTest(dimensionTestCase)
         self.TestSuite.addTest(commonTestCase)
